# Fonduecaquelon - fcq

MGMT of PyTorch training loops. Works best combined with chuchichaestli.

## SETUP
### Install UV
curl -LsSf https://astral.sh/uv/install.sh | sh

- Create Python env (tested on PY3.8)
- cd /fdq/
- pip install -e .

## USAGE
- general: `fdq path_to_experiment_file options`
- no training, for evaluation only: `-nt`
- auto test: `-ta`
- interactive test: `-ti`
- dump model: `-d`
- print model: `-p`





